<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>深度看图</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>版本：</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>深度看图是一款外观时尚，性能流畅的图片管理工具。</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>兼具了图片管理和图片查看功能，可以进行基本的图片编辑。</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>张图片</translation>
    </message>
    <message>
        <source>images</source>
        <translation>张图片</translation>
    </message>
    <message>
        <source>album</source>
        <translation>个相册</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>个相册</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>同步管理</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>正在同步：</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>未命名相册</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>最近导入</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>我的收藏</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>您确定要删除此相册吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>时间线</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加同步目录</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>您可以添加同步目录或拖拽图片到时间线</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>未命名相册</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>深度看图</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>张图片</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>是否将图片添加到该相册？</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>同步并创建</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>同步</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>是否添加到同步列表并创建以该文件夹命名的相册？</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>导出成功</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>导出失败</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>您确定将图片丢到回收站吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>此文件包含多个页面，推荐使用文档查看器查看所有页面。</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>复制到剪贴板</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>丢到回收站</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>从相册中移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>设为壁纸</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加同步目录</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>您可以添加同步目录或拖拽图片到时间线</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>添加到相册</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>添加到新相册</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>打开图片目录</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>没有权限查看图片</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>图片类型</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>拍摄时间</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改时间</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>分辨率</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>颜色空间</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光程序</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光时间</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>闪光灯</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>IOS感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>测光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>闪光灯补偿</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相机型号</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>镜头型号</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>无缩放</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>页面适应图像</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>图像适应页面</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>缩放至：</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>毫米</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>厘米</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>英寸</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>图像位置</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>缩放</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>图像设置</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>百叶窗</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>开关</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>滑移</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>圆环</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>选择目录</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>该目录不支持同步</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>添加文件夹</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>同步目录管理</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>目录列表为空</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>取消同步</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>张图片</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>移动设备已被移除</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>该目录已不存在</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>正在计算...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>查看图片</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>相册</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>退出幻灯片</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>丢到回收站</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>从相册中移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>设为壁纸</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一张</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一张</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>上一屏</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>下一屏</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>请输入新的快捷键</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>查看图片</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>相册</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>恢复默认</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>退出幻灯片</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>丢到回收站</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>从相册中移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>设为壁纸</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>退出幻灯片</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>暂停/播放</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>幻灯片设置</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>切换效果</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>时间</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>切换时间</translation>
    </message>
    <message>
        <source>second</source>
        <translation>秒</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>图片管理</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1视图</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>适应窗口</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Throw to Trash</source>
        <translation>丢到回收站</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>没有发现图片文件</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 张图片</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 张图片</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>同步管理</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>正在同步：</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>相册</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加同步目录</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>您可以添加同步目录或拖拽图片到时间线</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>添加到相册</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>添加到新相册</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>复制到剪贴板</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>丢到回收站</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>设为壁纸</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>幻灯片设置</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>效果</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>时间</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>相册</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>yyyy年MM月dd日</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>最近导入</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>深度看图是一款外观时尚，性能流畅的图片管理工具。</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>兼具了图片管理和图片查看功能，可以进行基本的图片编辑。</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>深色主题</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>时间线</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>添加到相册</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>添加到新相册</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>复制到剪贴板</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>丢到回收站</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>从相册中移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>显示导航窗口</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>隐藏导航窗口</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>设为壁纸</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
</context>
</TS>